==> jc-1.4.0.tar.gz: soot/tagkit/SourceLineNumberTag.h <==
// public class soot.tagkit.SourceLineNumberTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 801ded4adf91a761 soot_tagkit_SourceLineNumberTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceLineNumberTag_H_
#define _JC_soot_tagkit_SourceLineNumberTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceLineNumberTag$sub_refs	_jc_soot_tagkit_SourceLineNumberTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs	_jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$refs	_jc_soot_tagkit_SourceLineNumberTag$refs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$nonrefs	_jc_soot_tagkit_SourceLineNumberTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$object	_jc_soot_tagkit_SourceLineNumberTag$object;

typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vmethods	_jc_soot_tagkit_SourceLineNumberTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vtable	_jc_soot_tagkit_SourceLineNumberTag$vtable;
typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vtype	_jc_soot_tagkit_SourceLineNumberTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceLineNumberTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *, jint);
extern void _jc_soot_tagkit_SourceLineNumberTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *, jint, jint);

// Virtual methods
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getEndLineNumber$1fd2602ebc9cd616(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLineNumberTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getStartLineNumber$aaf2d15e300ee909(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_SourceLineNumberTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLineNumberTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getEndLineNumber$1fd2602ebc9cd616;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getStartLineNumber$aaf2d15e300ee909;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceLineNumberTag$vmethods {
	jint	(*getEndLineNumber$1fd2602ebc9cd616)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
	jint	(*getStartLineNumber$aaf2d15e300ee909)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *);
};

// Vtable
struct _jc_soot_tagkit_SourceLineNumberTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceLineNumberTag$vmethods	soot_tagkit_SourceLineNumberTag;
};

// Vtype
struct _jc_soot_tagkit_SourceLineNumberTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceLineNumberTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLineNumberTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceLineNumberTag$refs {
    _jc_soot_tagkit_SourceLineNumberTag$sub_refs	soot_tagkit_SourceLineNumberTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs {
	jint	startLineNumber;
	jint	endLineNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceLineNumberTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs	soot_tagkit_SourceLineNumberTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceLineNumberTag$object {
	_jc_soot_tagkit_SourceLineNumberTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceLineNumberTag$vtype	*vtype;
	_jc_soot_tagkit_SourceLineNumberTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceLineNumberTag$vtype _jc_soot_tagkit_SourceLineNumberTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceLineNumberTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceLineNumberTag$class_object;

#endif	/* _JC_soot_tagkit_SourceLineNumberTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/SourceLineNumberTag.h <==
// public class soot.tagkit.SourceLineNumberTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 801ded4adf91a761 soot_tagkit_SourceLineNumberTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_SourceLineNumberTag_H_
#define _JC_soot_tagkit_SourceLineNumberTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_SourceLineNumberTag$sub_refs	_jc_soot_tagkit_SourceLineNumberTag$sub_refs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs	_jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$refs	_jc_soot_tagkit_SourceLineNumberTag$refs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$nonrefs	_jc_soot_tagkit_SourceLineNumberTag$nonrefs;
typedef struct _jc_soot_tagkit_SourceLineNumberTag$object	_jc_soot_tagkit_SourceLineNumberTag$object;

typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vmethods	_jc_soot_tagkit_SourceLineNumberTag$vmethods;
typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vtable	_jc_soot_tagkit_SourceLineNumberTag$vtable;
typedef const struct _jc_soot_tagkit_SourceLineNumberTag$vtype	_jc_soot_tagkit_SourceLineNumberTag$vtype;

// Constructors
extern void _jc_soot_tagkit_SourceLineNumberTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *, jint) _JC_JCNI_ATTR;
extern void _jc_soot_tagkit_SourceLineNumberTag$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getEndLineNumber$1fd2602ebc9cd616(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLineNumberTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_tagkit_SourceLineNumberTag$method$getStartLineNumber$aaf2d15e300ee909(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_SourceLineNumberTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_SourceLineNumberTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getEndLineNumber$1fd2602ebc9cd616;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getStartLineNumber$aaf2d15e300ee909;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_SourceLineNumberTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_SourceLineNumberTag$vmethods {
	jint	(*getEndLineNumber$1fd2602ebc9cd616)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
	jint	(*getStartLineNumber$aaf2d15e300ee909)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_SourceLineNumberTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_SourceLineNumberTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_SourceLineNumberTag$vmethods	soot_tagkit_SourceLineNumberTag;
};

// Vtype
struct _jc_soot_tagkit_SourceLineNumberTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_SourceLineNumberTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLineNumberTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_SourceLineNumberTag$refs {
    _jc_soot_tagkit_SourceLineNumberTag$sub_refs	soot_tagkit_SourceLineNumberTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs {
	jint	startLineNumber;
	jint	endLineNumber;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_SourceLineNumberTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_SourceLineNumberTag$sub_nonrefs	soot_tagkit_SourceLineNumberTag;
};

// Object instance structure
struct _jc_soot_tagkit_SourceLineNumberTag$object {
	_jc_soot_tagkit_SourceLineNumberTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_SourceLineNumberTag$vtype	*vtype;
	_jc_soot_tagkit_SourceLineNumberTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_SourceLineNumberTag$vtype _jc_soot_tagkit_SourceLineNumberTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_SourceLineNumberTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_SourceLineNumberTag$class_object;

#endif	/* _JC_soot_tagkit_SourceLineNumberTag_H_ */
